@@ -16,6 +16,8 @@
 */
 
 #include "processjob.h"
+#include "cmake-paths.h"
+#include "purpose_external_process_debug.h"
 #include <QLibrary>
 #include <KRandom>
 #include <QMetaMethod>
@@ -24,6 +26,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QStandardPaths>
+#include <QCborValue>
 
 using namespace Purpose;
 
@@ -46,11 +49,9 @@ ProcessJob::ProcessJob(const QString &pluginPath, const QString &pluginType, con
     }
     m_process->setProcessChannelMode(QProcess::ForwardedChannels);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     connect(static_cast<QProcess *>(m_process), &QProcess::errorOccurred, this, [](QProcess::ProcessError error) {
-        qWarning() << "error!" << error;
+        qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG) << "error!" << error;
     } );
-#endif
     connect(static_cast<QProcess *>(m_process), &QProcess::stateChanged, this, &ProcessJob::processStateChanged);
 
     m_socket.setMaxPendingConnections(1);
@@ -73,8 +74,7 @@ void ProcessJob::writeSocket()
 
     m_socket.removeServer(m_socket.serverName());
 
-    const QJsonDocument doc(m_data);
-    const QByteArray data = doc.toBinaryData();
+    const QByteArray data = QCborValue::fromJsonValue(m_data).toCbor();
     m_localSocket->write(QByteArray::number(data.size()) + '\n');
     const auto ret = m_localSocket->write(data);
     Q_ASSERT(ret == data.size());
@@ -89,7 +89,7 @@ void ProcessJob::readSocket()
 
         const QJsonObject object = QJsonDocument::fromJson(json, &error).object();
         if (error.error != QJsonParseError::NoError) {
-            qWarning() << "error!" << error.errorString() << json;
+            qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG) << "error!" << error.errorString() << json;
             continue;
         }
 
@@ -116,7 +116,7 @@ void ProcessJob::start()
         QStringLiteral("--pluginPath"), m_pluginPath
     });
 
-    qDebug() << "launching..." << m_process->program() << m_process->arguments().join(QLatin1Char(' ')).constData();
+    qCDebug(PURPOSE_EXTERNAL_PROCESS_LOG) << "launching..." << m_process->program() << m_process->arguments().join(QLatin1Char(' ')).constData();
 
     m_process->start();
 }
@@ -126,7 +126,7 @@ void Purpose::ProcessJob::processStateChanged(QProcess::ProcessState state)
     if (state == QProcess::NotRunning) {
         Q_ASSERT(m_process->exitCode()!=0 || m_localSocket);
         if (m_process->exitCode()!=0) {
-            qWarning() << "process exited with code:" << m_process->exitCode();
+            qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG) << "process exited with code:" << m_process->exitCode();
         }
 
         do {
