@@ -18,12 +18,10 @@
 #include <purpose/pluginbase.h>
 #include "mpform.h"
 #include <QDebug>
-#include <QTimer>
 #include <QStandardPaths>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
-#include <QUrlQuery>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KJob>
@@ -42,7 +40,7 @@ class ImgurShareJob : public Purpose::Job
 {
     Q_OBJECT
     public:
-        ImgurShareJob(QObject* parent)
+        explicit ImgurShareJob(QObject* parent)
             : Purpose::Job(parent)
             , m_pendingJobs(0)
         {}
@@ -105,7 +103,7 @@ class ImgurShareJob : public Purpose::Job
         {
             Q_EMIT infoMessage(this, i18n("Uploading files to imgur..."));
             const QJsonArray urls = data().value(QStringLiteral("urls")).toArray();
-            foreach(const QJsonValue &val, urls) {
+            for (const QJsonValue &val : urls) {
                 QString u = val.toString();
                 KIO::StoredTransferJob* job = KIO::storedGet(QUrl(u));
                 connect(job, &KJob::finished, this, &ImgurShareJob::fileFetched);
@@ -172,6 +170,6 @@ class Q_DECL_EXPORT ImgurPlugin : public Purpose::PluginBase
         }
 };
 
-K_PLUGIN_FACTORY_WITH_JSON(ImgurShare, "imgurplugin.json", registerPlugin<ImgurPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(ImgurPlugin, "imgurplugin.json")
 
 #include "imgurplugin.moc"
