@@ -18,15 +18,11 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <QDialog>
 #include <QUrl>
-#include <QVariantList>
 #include <QStandardPaths>
 #include <QJsonArray>
 
-#include <KLocalizedString>
 #include <KPluginFactory>
-#include <QJsonDocument>
 
 #include "reviewboardjobs.h"
 #include "debug.h"
@@ -38,7 +34,7 @@ class TheReviewboardJob : public Purpose::Job
 {
     Q_OBJECT
     public:
-        TheReviewboardJob(QObject* object = Q_NULLPTR)
+        TheReviewboardJob(QObject* object = nullptr)
             : Purpose::Job(object)
     {}
 
@@ -115,14 +111,14 @@ class Q_DECL_EXPORT ReviewBoardPlugin : public Purpose::PluginBase
     Q_OBJECT
     public:
         ReviewBoardPlugin(QObject* parent, const QList<QVariant>& /*args*/) : PluginBase(parent) {}
-        virtual ~ReviewBoardPlugin() override {}
+        ~ReviewBoardPlugin() override {}
 
-        virtual Purpose::Job* createJob() const override
+        Purpose::Job* createJob() const override
         {
             return new TheReviewboardJob;
         }
 };
 
-K_PLUGIN_FACTORY_WITH_JSON(ReviewBoardPluginFactory, "reviewboardplugin.json", registerPlugin<ReviewBoardPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(ReviewBoardPlugin, "reviewboardplugin.json")
 
 #include "reviewboardplugin.moc"
